@@ -15,7 +15,7 @@
  * this source code; if not, write to:
  * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * "$Id: gtk_ctrl.cpp,v 1.16 2004/01/16 19:03:07 jaromil Exp $"
+ * "$Id: gtk_ctrl.cpp 229 2004-09-19 03:13:41Z jaromil $"
  *
  */
 
@@ -55,6 +55,7 @@ static GtkTreeStore *effect_store;
 static GtkTreeIter effect_iter;
 
 static GtkMenu *menu_effect;
+static GtkMenu *menu_blit = NULL;
 
 /* direct pointer to FreeJ environment */
 static Context *env;
@@ -91,6 +92,54 @@ void on_about(GtkWidget *widget, gpointer *data) {
   func("%s(%p,%p)",__FUNCTION__,widget,data);
   env->osd.credits();
 }
+
+/* =========== BLIT */
+
+
+void on_select_blit(char *name) {
+  if(menu_blit)
+    gtk_menu_set_active(menu_blit,0);
+  Layer *lay = (Layer*) env->layers.selected();
+  if(!lay) {
+    error("no layer selected to change blit to %s",name); return; }
+  lay->blitter.set_blit(name);
+}
+
+void update_blit_menu() {
+  GtkOptionMenu *option_menu_blit;
+  GtkWidget *item;
+  
+  option_menu_blit = (GtkOptionMenu*) glade_xml_get_widget(gtk,"menu_blit");
+  if(!option_menu_blit) {
+    error("glade file corrupted: menu_blit symbol not found");
+    return;
+  }
+
+  /* cleanup previous menu */
+  if(menu_blit) delete menu_blit;
+  menu_blit = (GtkMenu*)gtk_menu_new();
+
+  gtk_menu_set_title(menu_blit,"Blit mode");
+  item = gtk_menu_item_new_with_label("Blit mode");
+  gtk_menu_shell_append(GTK_MENU_SHELL(menu_blit),item);
+ 
+  Layer *lay = (Layer*)env->layers.selected();
+  Entry *ptr = lay->blitter.blitlist.begin();
+  while(ptr) {
+    item = gtk_menu_item_new_with_label(ptr->name);
+    gtk_widget_show(item);
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu_blit),item);
+    g_signal_connect_swapped(G_OBJECT(item),"activate",
+			     G_CALLBACK(on_select_blit),
+			     (gpointer)ptr->name);
+    ptr = ptr->next;
+  }
+  gtk_option_menu_set_menu(option_menu_blit,
+			   (GtkWidget*)menu_blit);
+}
+
+
+
 void do_add_layer(GtkWidget *widget, gpointer *data) {
   Layer *lay;
   char **sel = gtk_file_selection_get_selections(GTK_FILE_SELECTION(data));
@@ -99,7 +148,7 @@ void do_add_layer(GtkWidget *widget, gpointer *data) {
     lay = create_layer(sel[c]);
     if(!lay) return;
     if(lay->init(env)) {
-      if(lay) env->layers.add(lay);
+      env->layers.add(lay);
       env->layers.sel(0); /* deselect others */
       lay->sel(true);
     } else delete lay;
@@ -144,46 +193,17 @@ void on_layer_delete(GtkWidget *widget, gpointer *data) {
 void on_layer_up(GtkWidget *widget, gpointer *data) {
   func("%s(%p,%p)",__FUNCTION__,widget,data);
   Layer *laysel = (Layer*) env->layers.selected();
-  if(laysel) laysel->up(); }
+  if(laysel) laysel->up(); 
+}
 void on_layer_down(GtkWidget *widget, gpointer *data) {
   func("%s(%p,%p)",__FUNCTION__,widget,data);
   Layer *laysel = (Layer*) env->layers.selected();
-  if(laysel) laysel->down(); }
-void on_blit_rgb(GtkWidget *widget, gpointer *data) {
-  func("%s(%p,%p)",__FUNCTION__,widget,data);
-  Layer *laysel = (Layer*) env->layers.selected();
-  if(laysel) laysel->set_blit(1); }
-void on_blit_red(GtkWidget *widget, gpointer *data) {
-  func("%s(%p,%p)",__FUNCTION__,widget,data);
-  Layer *laysel = (Layer*) env->layers.selected();
-  if(laysel) laysel->set_blit(4); }
-void on_blit_green(GtkWidget *widget, gpointer *data) {
-  func("%s(%p,%p)",__FUNCTION__,widget,data);
-  Layer *laysel = (Layer*) env->layers.selected();
-  if(laysel) laysel->set_blit(3); }
-void on_blit_blue(GtkWidget *widget, gpointer *data) {
-  func("%s(%p,%p)",__FUNCTION__,widget,data);
-  Layer *laysel = (Layer*) env->layers.selected();
-  if(laysel) laysel->set_blit(2); }
-void on_blit_add(GtkWidget *widget, gpointer *data) {
-  func("%s(%p,%p)",__FUNCTION__,widget,data);
-  Layer *laysel = (Layer*) env->layers.selected();
-  if(laysel) laysel->set_blit(5); }
-void on_blit_sub(GtkWidget *widget, gpointer *data) {
-  func("%s(%p,%p)",__FUNCTION__,widget,data);
-  Layer *laysel = (Layer*) env->layers.selected();
-  if(laysel) laysel->set_blit(6); }
-void on_blit_and(GtkWidget *widget, gpointer *data) {
-  func("%s(%p,%p)",__FUNCTION__,widget,data);
-  Layer *laysel = (Layer*) env->layers.selected();
-  if(laysel) laysel->set_blit(7); }
-void on_blit_or(GtkWidget *widget, gpointer *data) {
-  func("%s(%p,%p)",__FUNCTION__,widget,data);
-  Layer *laysel = (Layer*) env->layers.selected();
-  if(laysel) laysel->set_blit(8); }
+  if(laysel) laysel->down(); 
+}
+
 void on_osd(GtkWidget *widget, gpointer *data) {
   func("%s(%p,%p)",__FUNCTION__,widget,data);
-  env->osd.active(); }
+  env->osd.active = !env->osd.active; }
 void on_overwrite(GtkWidget *widget, gpointer *data) {
   func("%s(%p,%p)",__FUNCTION__,widget,data);
   env->clear_all = !env->clear_all; }
@@ -201,9 +221,10 @@ void on_layer_select(GtkTreeSelection *sel, gpointer data) {
     gtk_tree_model_get(model,&layer_iter,LAYER_OBJ,&laysel,-1);
     if(laysel) {
       func("selected %s Layer %s (%p)",
-	   laysel->getname(),laysel->get_filename(),laysel);
+	   laysel->get_name(),laysel->get_filename(),laysel);
       env->layers.sel(0); /* deselect all */
       laysel->sel(true); /* select the one */
+      update_blit_menu();
     }
   }
 }
@@ -308,8 +329,10 @@ void update_layer_list() {
     gtk_tree_store_append(layer_store,&iter,NULL);
     gtk_tree_store_set(layer_store,&iter,
 		       LAYER_ACTIVE,lay->active,
-		       LAYER_NAME,lay->getname(),
-		       LAYER_BLIT,lay->get_blit(),
+		       LAYER_NAME,lay->get_name(),
+		       LAYER_BLIT,
+		       (lay->blitter.current_blit)?
+		       lay->blitter.current_blit->get_name():" ",
 		       LAYER_FILE,lay->get_filename(),
 		       LAYER_OBJ,lay,
 		       -1);
@@ -336,7 +359,7 @@ void on_effect_select(GtkTreeSelection *sel, gpointer data) {
       Layer *laysel = (Layer*) env->layers.selected();
       if(!laysel) return;
       func("selected effect %s on layer %s",
-	   effsel->getname(), laysel->getname());
+	   effsel->getname(), laysel->get_name());
       laysel->filters.sel(0); /* deselect all */
       effsel->sel(true); /* select the one */
     }
@@ -437,16 +460,20 @@ void init_effect_menu() {
   gtk_option_menu_set_menu(option_menu_effect,(GtkWidget*)menu_effect);
 }
 
+
 void *gtk_run(void *arg) {
   while(!quit) {
     update_layer_list();
+    jsleep(0,100);
     update_effect_list();
-    jsleep(0,200);
+    jsleep(0,100);
     gdk_threads_enter();
-    while(gtk_events_pending())
+    while(gtk_events_pending()) {
+      jsleep(0,50);
       gtk_main_iteration();
+    }
     gdk_threads_leave();
-    jsleep(0,200);
+    jsleep(0,100);
   }
   return(NULL);
 }
@@ -477,14 +504,16 @@ bool gtk_ctrl_init(Context *nenv, int *argc, char **argv) {
   } else fclose(ftmp);
 
   env = nenv;
+
   gtk_init(argc, &argv);
+
   gtk = glade_xml_new(guipath,NULL,NULL);
+
+  g_thread_init(NULL);
   
   /* connect signal handlers 
      glade_xml_signal_autoconnect(gtk); */
 
-  /* signal to glib we're going to use threads */
-  g_thread_init(NULL);
 
   /* connect signals to callbacks */
   CONNECT("fullscreen","activate",on_fullscreen);
@@ -499,14 +528,6 @@ bool gtk_ctrl_init(Context *nenv, int *argc, char **argv) {
   CONNECT("button_layer_down","clicked",on_layer_down);
   CONNECT("button_layer_delete","clicked",on_layer_delete);
   CONNECT("checkbutton_layer_active","clicked",on_layer_active);
-  CONNECT("blit_rgb","activate",on_blit_rgb);
-  CONNECT("blit_red","activate",on_blit_red);
-  CONNECT("blit_green","activate",on_blit_green);
-  CONNECT("blit_blue","activate",on_blit_blue);
-  CONNECT("blit_add","activate",on_blit_add);
-  CONNECT("blit_sub","activate",on_blit_sub);
-  CONNECT("blit_and","activate",on_blit_and);
-  CONNECT("blit_or","activate",on_blit_or);
 
   CONNECT("button_effect_up","clicked",on_effect_up);
   CONNECT("button_effect_down","clicked",on_effect_down);  
@@ -516,7 +537,7 @@ bool gtk_ctrl_init(Context *nenv, int *argc, char **argv) {
   init_layer_list();
   init_effect_list();
   init_effect_menu();
-
+  
   quit = false;
   if(pthread_attr_init (&_attr) == -1)
     error("error initializing POSIX thread attribute");
