@@ -19,13 +19,21 @@
 #ifndef __UTILS_H__
 #define __UTILS_H__
 
-#include <SDL.h>
+#include <inttypes.h>
+#include <errno.h>
+#include <console.h>
+
+extern char msg[255];
+
+extern void *(*jmemcpy)( void *to, const void *from, size_t len );
+void jmemset(void * s, unsigned long c ,size_t count);
 
 void set_debug(int lev);
 int get_debug();
 void set_osd(char *st);
 void show_osd();
 void show_osd(char *format, ...);
+void set_console(Console *c);
 void notice(char *format, ...);
 void func(char *format, ...);
 void error(char *format, ...);
@@ -33,9 +41,16 @@ void act(char *format, ...);
 void warning(char *format, ...);
 void *jalloc(void *point,size_t size);
 bool jfree(void *point);
-Uint32 fastrand();
-void fastsrand(Uint32 seed);
+uint32_t fastrand();
+void fastsrand(uint32_t seed);
 double dtime();
 bool set_rtpriority(bool max);
 void jsleep(int sec, long nsec);
+int rtc_open();
+unsigned long rtc_tick();
+void rtc_freq_set(unsigned long freq);
+void rtc_freq_wait();
+void rtc_close();
 #endif
+
+
