@@ -20,6 +20,8 @@
 #define __png_h__
 
 #include <stdio.h>
+#include <SDL/SDL.h>
+
 #include <png.h>
 #include <layer.h>
 
@@ -34,12 +36,21 @@ private:
   /* file signature to check for validation */
   unsigned char sig[8];
 
-  /* image buffer */
-  png_bytep buf;
-  
   /* row pointers */
   png_bytep *row_pointers;
 
+  /* black image */
+  void *black_image;
+
+  void *png_image;
+
+  /** how many times show image  when in subliminal mode */
+  int subliminal;
+
+  bool blinking;
+
+  int count;
+
   FILE *fp;
 
 public:
@@ -51,6 +62,8 @@ public:
   void *feed();
 
   void close();
+  
+  bool keypress(char key);
 };
 
 #endif
