@@ -15,7 +15,7 @@
  * this source code; if not, write to:
  * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * "$Id: sdl_screen.h,v 1.3 2003/12/29 23:12:11 jaromil Exp $"
+ * "$Id: sdl_screen.h 227 2004-09-17 11:58:33Z jaromil $"
  *
  */
 
@@ -31,8 +31,9 @@ class SdlScreen : public ViewPort {
   ~SdlScreen();
 
   bool init(int widt, int height);
-  void blit(Layer *layer);
-  void crop(Layer *layer);
+  void set_magnification(int algo);
+  void resize(int resize_w, int resize_h);
+
   void show();
   void clear();
 
@@ -40,9 +41,7 @@ class SdlScreen : public ViewPort {
   void *get_surface();
 
   SDL_Surface *screen;
-  SDL_Surface *emuscr;
-  void *surface;
-
+  SDL_Surface *surface;
   void *coords(int x, int y);
 
   bool lock();
@@ -50,21 +49,11 @@ class SdlScreen : public ViewPort {
  
  private:
   int setres(int wx, int hx);
+  SDL_Surface *emuscr;
   
   bool dbl;
   uint32_t sdl_flags;
 
-  /* blit stuff */
-  uint32_t blit_x, blit_y;
-  uint32_t blit_width, blit_height;
-  uint32_t blit_offset;
-  uint32_t *blit_coords;
-  /* small vars used in blits */
-  int chan, c, cc;
-  uint32_t *scr, *pscr, *off, *poff;
-  uint8_t *alpha;
-
-  SDL_Surface *blitter;
 };
 
 #endif 
